@@ -5,7 +5,7 @@ home.__init__
 A simple module that defines how the flask app is created.
 
 """
-__version__ = '0.2.0'
+__version__ = '0.3.0'
 
 from os import environ
 
@@ -15,8 +15,11 @@ from flask.ext.login import LoginManager
 from flask.ext.migrate import Migrate
 from flask.ext.sqlalchemy import SQLAlchemy
 
+from home.ts.redis import RedisSeries
+
 
 db = SQLAlchemy()
+redis_series = RedisSeries()
 login_manager = LoginManager()
 
 
