@@ -34,15 +34,26 @@ function device_series_graph(device_id, series_id, id){
 
             $.each(data.data, function(x, result){
 
-                var plot_data = [];
+                $.each(result, function(graph_name, points){
+
+                    var plot_data = [];
+
+                    $.each(points, function(i, point){
+
+                        var date = point[0];
+                        var value = point[1];
+
+                        if (plot_data.length == 0 || value > max) max = value;
+                        if (plot_data.length == 0 || value < min) min = value;
+
+                        plot_data.push([new Date(date), value]);
+
+                    })
+
+                    series.push(plot_data);
 
-                $.each(result.values, function(i, v){
-                    if (i == 0 || v.value > max) max = v.value;
-                    if (i == 0 || v.value < min) min = v.value;
-                    plot_data.push([new Date(v.created_at), v.value])
                 });
 
-                series.push(plot_data);
 
             });
 
@@ -113,13 +124,11 @@ $(function(){
 
         var original = val.src;
 
-        console.log(original);
-
         var reloader = function(){
             var new_src = original + "?z=" + new Date().getTime();
             console.log(new_src);
             val.src = new_src;
-            setTimeout(reloader, 1000);
+            setTimeout(reloader, 10000);
         }
 
         reloader()
